summaryrefslogtreecommitdiff
path: root/regcomp.c
diff options
context:
space:
mode:
authorKarl Williamson <public@khwilliamson.com>2010-12-12 11:28:20 -0700
committerKarl Williamson <public@khwilliamson.com>2010-12-12 13:13:45 -0700
commit929fffa4acb2dedab3293617c11903a4914d8fdf (patch)
tree20f3e450dbab6c7d1e9002cfbbe483379b71bbec /regcomp.c
parent09b1cffef8cddfec3f726ac733cd648d5b6c28c6 (diff)
downloadperl-929fffa4acb2dedab3293617c11903a4914d8fdf.tar.gz
blead breaks Attribute::Constant
The problem is that I confused FOLD with ANYOF_FOLD, and as a result, emitted a locale regnode, which is tainted. Any tests that required non-tainting started failing
Diffstat (limited to 'regcomp.c')
-rw-r--r--regcomp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/regcomp.c b/regcomp.c
index 66cadcf3e0..eb34b16553 100644
--- a/regcomp.c
+++ b/regcomp.c
@@ -8955,8 +8955,8 @@ parseit:
/* (A locale node can have 1 point and be folded; all the other folds
* will include the fold, hence will have 2 points, so we won't get
- * here with FOLD set unless it is also locale) */
- ret = reg_node(pRExC_state, (U8) (! FOLD)
+ * here with ANYOF_FOLD set unless it is also locale) */
+ ret = reg_node(pRExC_state, (U8) (! (ANYOF_FLAGS(ret) & ANYOF_FOLD))
? EXACT
: EXACTFL
);